MethodChannelFlutterSteamworks class

An implementation of FlutterSteamworksPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAchievement(String achievementId) Future<bool>
override
getAchievement(String achievementId) Future<bool>
override
getPlatformVersion() Future<String?>
override
initSteam(int appId) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestCurrentStats() Future<bool>
override
setAchievement(String achievementId) Future<bool>
override
storeStats() Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited